<h1 align="center">ALU-PYQUEST🐍💻</h1>

<img src="https://github.com/Elhameed/ALU-PYQUEST/blob/main/pythonquiz.jpg" />

ALU PYQUEST is a game designed to test your knowledge of Python programming language. It consists of a series of questions related to the Python curriculum, presented one at a time, starting from beginner's level to advanced level. You will have a limited time to answer each question, and for each correct answer, you will earn 10 points, while for each incorrect answer or if you run out of time, 5 points will be deducted from your score.

## Table of Contents 📑
- [Getting Started](#getting-started)
- [Prerequisites](#prerequisites)
- [How To Play](#how-to-play)
- [Screenshots](#screenshots)
- [Demo Video](#demo-video)
- [License](#license)
- [Contributors](#contributors)
- [Acknowlegdement](#acknowledgement)

## Getting Started 🚀
To get started with ALU-PYQUEST, simply follow these steps:
1. Clone the repository onto your local machine using the following command::
```sh
git clone https://github.com/Elhameed/ALU-PYQUEST.git
```
2. Navigate into the cloned repository by running the following command in your terminal:
```sh
cd ALU-PYQUEST
```
3. Run the game by executing the following command in your terminal:
```sh
python3 quiz.py
```

## Prerequisites 📋
Before you begin, ensure you have met the following requirements:
- You have installed the latest version of Python.
- You have a basic understanding of Python programming language.

## How To Play 🎮
1. Open the terminal and navigate to the project directory.
2. Run the following command to start the game:
```sh
user@User:~/$ python3 quiz.py
```
4. Read the question and choose the correct answer from the given options.
5. You have `25` seconds to answer each question.
6. For each correct answer, you will earn `10` points.
7. For each incorrect answer or if you run out of time, `5` points will be deducted from your score.
8. At the end of the game, you will see your total score.

## Screenshots 📷
Coming soon...

## Demo Video 🎥
You can find a demo of the game at the following link: https://youtu.be/demo-video-link

## License :scroll:
ALU-PYQUEST is licensed under the MIT License. See the [LICENSE](./LICENSE) file for more information.

## Contributors 👥
- [Sadick Achuli](https://github.com/Sadickachuli)
- [Abdulhameed Teniola Ajani](https://github.com/Elhameed)
- [Noella Uwayo](https://github.com/n-uwayo)
- [Sabir Walid](https://github.com/SabirWalid)
- [Mohammed Yasin](https://github.com/MohamedAYasin)
- [Iranzi Prince](https://github.com/iranziprince01)
- [Innocent Manzi](https://github.com/innocentmanzi)
- [Iraduhaye Bukuru Paterne](https://github.com/IraduhayeBukuruPaterne1)

## Acknowledgement 🙏
- Special thanks to our instructor, [Mr. Hervé Musangwa](https://www.linkedin.com/in/hervé-musangwa-67478a112/) for reviewing our project and providing feedback that helped improve its quality.
- We also want to acknowledge the BSE Faculty for challenging us to apply the technologies we learned during the term to develop a project that showcases our skills and knowledge in the field.

----------
- If you found ALU-PYQUEST useful, please consider giving this repo a star ⭐️!
